@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-ver = "0.10.30.13.21"
+ver = "0.10.110.18.13"
 """
 autor Bartlomiej Ceglik
 e-mail yoyoek[no spam]wp.pl
@@ -233,7 +233,7 @@ def Run_import( dialog = '' ):
         cal_nr = cal_nr+1
 
         work_type = 'internet'
-        print "--------------- DETECT WORK TYPE ------------------------"
+        print "\n\n--------------- DETECT WORK TYPE ------------------------"
         work_path = ical[0]
         if work_path[:1] == '/':
             print 'local work [%s]' % work_path
@@ -242,12 +242,15 @@ def Run_import( dialog = '' ):
         elif work_path[:7] == 'http://':
             ical[0] = work_path[7:]
             print '1 internet work [%s] => [%s]' % (work_path, ical[0] )
+        elif work_path[:9] == 'webcal://':
+            ical[0] = work_path[9:]
+            print '1 internet work [%s] => [%s] (webcal://)' % (work_path, ical[0] )
         elif work_path[:4] == 'www.':
             ical[0] = work_path[4:]
             print '2 internet work [%s] => [%s]' % (work_path, ical[0] )
         else:
             print '3 internet work [%s] ' % (ical[0] )
-        print "--------------- DETECT WORK TYPE ------------------------"
+        print "--------------- DETECT WORK TYPE ------------------------\n\n"
 
 
         if work_type == 'internet':
